// $Id: ungrab.h,v 1.7 1999/08/19 11:29:00 andreas Exp $ -*- C++ -*-
// Ungrab frozen mouse pointer

// Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@gnu.org>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.gnu.org/software/ddd/',
// or send a mail to the DDD developers <ddd@gnu.org>.

#ifndef _DDD_ungrab_h
#define _DDD_ungrab_h

#ifdef __GNUG__
#pragma interface
#endif

#include "bool.h"

// If START is true, initiate grab check.  If START is false, stop it.
void check_grabs(bool start);

#endif // _DDD_ungrab_h
// DON'T ADD ANYTHING BEHIND THIS #endif
